@@ -1,11 +1,11 @@
 '''title'''
 __title__ = 'videofetch'
 '''description'''
-__description__ = 'A lightweight video downloader written by pure python'
+__description__ = 'Videodl: A lightweight video downloader written by pure python'
 '''url'''
 __url__ = 'https://github.com/CharlesPikachu/videodl'
 '''version'''
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 '''author'''
 __author__ = 'Charles'
 '''email'''
